Read the random forest from a file or connection using light-weight serialization for C++ objects.
read_literanger(file, verbose = FALSE, ...)A literanger random forest object
A connection or the name of a file containing a serialized
literanger object.
Show additional serialization information (not implemented).
Further arguments passed to readRDS().
stephematician <stephematician@gmail.com
This function uses 'cereal' light-weight serialization to
read a literanger object (random forest) from a file or connection. The
file is usually the result of a call to write_literanger(). The random
forest returned can be used for prediction immediately upon return, and does
not require the original training data or training environment.
write_literanger() readRDS